@@ -29,4 +29,8 @@ return ['routes' => [
     ['name' => 'notes_api#destroy', 'url' => '/api/v0.2/notes/{id}', 'verb' => 'DELETE'],
     ['name' => 'notes_api#preflighted_cors', 'url' => '/api/v0.2/{path}',
      'verb' => 'OPTIONS', 'requirements' => ['path' => '.+']],
+
+	// settings
+	['name' => 'settings#set', 'url' => '/settings', 'verb' => 'PUT'],
+	['name' => 'settings#get', 'url' => '/settings', 'verb' => 'GET'],
 ]];
