@@ -6,14 +6,15 @@ OC.L10N.register(
     "The notes folder is not accessible: %s" : "Složka s poznámkami není přístupná: %s",
     "New note" : "Nová poznámka",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Máte neuložené poznámky. Opuštění stránky zahodí všechny změny!",
+    "Please wait while new settings are applied…" : "Vyčkejte než se nová nastavení uplatní…",
     "_%n word_::_%n words_" : ["%n slovo","%n slova","%n slov","%n slov"],
-    "An error occurred!" : "Došlo k chybě!",
     "File error" : "Chyba souboru",
     "Encryption Error" : "Chyba šifrování",
     "Error" : "Chyba",
     "Distraction-free notes and writing" : "Pozornost nerozptylující poznámky a texty",
     "Delete note" : "Smazat poznámku",
     "Favorite" : "Oblíbené",
+    "No search result for {{search}}" : "Žádné výsledky hledání pro {{search}}",
     "No notes found" : "Nebyly nalezeny žádné poznámky",
     "Settings" : "Nastavení",
     "Folder to store your notes" : "Složka pro ukládání vašich poznámek",
