@@ -6,15 +6,20 @@ OC.L10N.register(
     "The notes folder is not accessible: %s" : "תיקיית הפתקים אינה נגישה: %s",
     "New note" : "הערה חדשה",
     "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
+    "Please wait while new settings are applied…" : "נא להמתין בשעה שההגדרות החדשות מוחלות…",
     "_%n word_::_%n words_" : ["%n מילה","%n מילים","%n מילים","%n מילים"],
-    "An error occurred!" : "אירעה שגיאה!",
     "File error" : "שגיאת קובץ",
     "Encryption Error" : "שגיאת הצפנה",
     "Error" : "שגיאה",
     "Distraction-free notes and writing" : "פתקים וכתיבה ללא הסחות דעת",
     "Delete note" : "מחיקת הערה",
     "Favorite" : "מועדף",
+    "No search result for {{search}}" : "אין תוצאות לחיפוש אחר {{search}}",
     "No notes found" : "לא נמצאו הערות",
+    "Settings" : "הגדרות",
+    "Folder to store your notes" : "תיקייה לאחסון הפתקיות שלך",
+    "path to notes" : "נתיב לפתקיות",
+    "File extension for new notes" : "סיומת קובץ לפתקיות חדשות",
     "The note has unsaved changes." : "יש שינויים בהערה שלא נשמרו",
     "*" : "*",
     "Click here to try again" : "יש ללחוץ כאן כדי לנסות שוב",
