@@ -6,6 +6,7 @@ OC.L10N.register(
     "_%n word_::_%n words_" : ["%n fjalë","%n fjalë"],
     "Delete note" : "Fshije shënimin",
     "Favorite" : "E preferuar",
-    "No notes found" : "Asnjë shënim nuk u gjet"
+    "No notes found" : "Asnjë shënim nuk u gjet",
+    "Note saved" : "Shënim i ruajtuar"
 },
 "nplurals=2; plural=(n != 1);");
