@@ -16,7 +16,7 @@ use OCP\IL10N;
 use OCP\Files\IRootFolder;
 use OCP\Files\Folder;
 use OCP\ILogger;
-use OC\Encryption\Exceptions\DecryptionFailedException;
+use OCP\Encryption\Exceptions\GenericEncryptionException;
 use League\Flysystem\FileNotFoundException;
 use OCA\Notes\Db\Note;
 use OCA\Notes\Service\SettingsService;
@@ -106,12 +106,12 @@ class NotesService {
     }
 
     private function getNote($file, $notesFolder, $tags=[], $onlyMeta=false) {
-        $id=$file->getId();
+        $id = $file->getId();
         try {
-            $note=Note::fromFile($file, $notesFolder, $tags, $onlyMeta);
+            $note = Note::fromFile($file, $notesFolder, $tags, $onlyMeta);
         } catch(FileNotFoundException $e){
             $note = Note::fromException($this->l10n->t('File error').': ('.$file->getName().') '.$e->getMessage(), $file, $notesFolder, array_key_exists($id, $tags) ? $tags[$id] : []);
-        } catch(DecryptionFailedException $e) {
+        } catch(GenericEncryptionException $e) {
             $note = Note::fromException($this->l10n->t('Encryption Error').': ('.$file->getName().') '.$e->getMessage(), $file, $notesFolder, array_key_exists($id, $tags) ? $tags[$id] : []);
         } catch(\Exception $e) {
             $note = Note::fromException($this->l10n->t('Error').': ('.$file->getName().') '.$e->getMessage(), $file, $notesFolder, array_key_exists($id, $tags) ? $tags[$id] : []);
@@ -133,9 +133,14 @@ class NotesService {
         // check new note exists already and we need to number it
         // pass -1 because no file has id -1 and that will ensure
         // to only return filenames that dont yet exist
-        $path = $this->generateFileName($folder, $title, $this->settings->get('fileSuffix'), -1);
+        $path = $this->generateFileName($folder, $title, $this->settings->get($userId, 'fileSuffix'), -1);
         $file = $folder->newFile($path);
 
+        // If server-side encryption is activated, the server creates an empty file without signature
+        // which leads to an GenericEncryptionException('Missing Signature') afterwards.
+        // Saving a space-char (and removing it later) is a working work-around.
+        $file->putContent(' ');
+
         return $this->getNote($file, $folder);
     }
 
@@ -314,7 +319,7 @@ class NotesService {
      * @return Folder
      */
     private function getFolderForUser ($userId) {
-        $path = '/' . $userId . '/files/' . $this->settings->get('notesPath');
+        $path = '/' . $userId . '/files/' . $this->settings->get($userId, 'notesPath');
         try {
             $folder = $this->getOrCreateFolder($path);
         } catch(\Exception $e) {
