@@ -8,18 +8,15 @@
 
 
 script('notes', [
-    'vendor/bootstrap/tooltip',
     'vendor/angular/angular',
     'vendor/angular-route/angular-route',
     'vendor/restangular/dist/restangular',
-    'vendor/underscore/underscore',
     'vendor/simplemde/dist/simplemde.min',
     'public/app.min'
 ]);
 
 style('notes', [
     '../js/vendor/simplemde/dist/simplemde.min',
-    'vendor/bootstrap/tooltip',
     'notes'
 ]);
 
@@ -33,6 +30,13 @@ style('notes', [
     </script>
 
     <div id="app-navigation" ng-controller="NotesController" ng-class="{'loading': !notesLoaded}">
+        <!-- new note button -->
+        <div class="app-navigation-new">
+            <button class="icon-add" id="new-note-button" type="button" ng-click="create()">
+                <?php p($l->t('New note')); ?> 
+            </button>
+        </div>
+
         <ul>
 <?php if(!$_['useSearchAPI']) { ?>
             <li class="note-search">
@@ -41,18 +45,11 @@ style('notes', [
                 </span>
             </li>
 <?php } ?>
-            <!-- new note button -->
-            <div id="note-add">            
-                <button class="icon-add app-content-list-button ng-binding" id="new-note-button" type="button" name="button" ng-click="create()"
-                oc-click-focus="{ selector: '#app-content textarea' }">
-                    <?php p($l->t('New note')); ?> 
-                </button>
-            </div>
             <!-- notes list -->
             <li ng-repeat="note in filteredNotes = (notes| and:search | orderBy:['-favorite','-modified'])"
                 ng-class="{ active: note.id == route.noteId,'has-error': note.error }">
-                <a href="#/notes/{{ note.id }}" title="{{ note.title | noteTitle }}">
-                    {{ note.title | noteTitle }}
+                <a href="#/notes/{{ note.id }}" title="{{ note.title }}">
+                    {{ note.title }}
                     <span ng-if="note.unsaved">*</span>
                 </a>
                 <div class="app-navigation-entry-utils" ng-class="{'hidden': note.error }">
@@ -62,6 +59,7 @@ style('notes', [
                                 title="<?php p($l->t('Delete note')); ?>"
                                 notes-tooltip
                                 data-placement="bottom"
+                                data-trigger="hover"
                                 ng-click="delete(note.id)"></button>
                         </li>
 			<li class="app-navigation-entry-utils-menu-button button-star"
@@ -71,7 +69,8 @@ style('notes', [
                                 title="<?php p($l->t('Favorite')); ?>"
                                 notes-tooltip
                                 data-placement="bottom"
-                                ng-click="toggleFavorite(note.id)"
+                                data-trigger="hover"
+                                ng-click="toggleFavorite(note.id, $event)"
                                 ng-class="{'icon-starred': note.favorite}"></button>
                         </li>
                     </ul>
@@ -100,7 +99,7 @@ style('notes', [
             </div>
             <div class="settings-fileSuffix">
                 <p class="settings-hint"><label for="fileSuffix"><?php p($l->t('File extension for new notes')) ?></label></p>
-                <select id="fileSuffix" ng-model="settings.fileSuffix" ng-options="o as o for o in extensions"></select><input type="submit" class="icon-confirm" value="">
+                <select id="fileSuffix" ng-model="settings.fileSuffix" ng-options="o as o for o in extensions"></select>
             </div>
             </div>
         </div>
